@@ -20,6 +20,7 @@
  * Foundation, Inc.,  59 Temple Place - Suite 330, Cambridge, MA 02139, USA.
  */
 
+#include <config.h>
 #include "libgnomeP.h"
 
 struct _GnomePaper
@@ -42,13 +43,15 @@ static const GnomeUnit units[] =
   /* XXX does anyone *really* measure paper size in feet?  meters? */
 
   /* human name, abreviation, points per unit */
-  { "Feet",       "ft",	864 },
-  { "Meter",      "m",  2834.6457 },
-  { "Decimeter",  "dm",	283.46457 },
-  { "Millimeter", "mm",	2.8346457 },
-  { "Point",      "pt",	1. },
-  { "Centimeter", "cm",	28.346457 },
-  { "Inch",       "in",	72 },
+
+  /* units for paper sizes */
+  { N_("Feet"),       "ft",	864 },
+  { N_("Meter"),      "m",  2834.6457 },
+  { N_("Decimeter"),  "dm",	283.46457 },
+  { N_("Millimeter"), "mm",	2.8346457 },
+  { N_("Point"),      "pt",	1. },
+  { N_("Centimeter"), "cm",	28.346457 },
+  { N_("Inch"),       "in",	72 },
   { 0 }
 };
 
@@ -101,7 +104,7 @@ paper_init (void)
   for (unit=units; unit->name; unit++)
     {
       unit_list = g_list_prepend(unit_list, (gpointer) unit);
-      unit_name_list = g_list_prepend(unit_name_list, unit->name);
+      unit_name_list = g_list_prepend(unit_name_list, _(unit->name));
     }
 }
 
@@ -114,7 +117,7 @@ paper_name_compare (const GnomePaper* a, const gchar *b)
 static int 
 unit_name_compare (const GnomeUnit* a, const gchar *b)
 {
-  return (g_strcasecmp(a->name, b));
+  return (g_strcasecmp(_(a->name), b));
 }
 
 
