@@ -59,7 +59,7 @@ struct _GnomeProcBar {
 
 	unsigned *last;
 
-	gint (*cb)();
+	gint (*cb)(gpointer);
 	gpointer cb_data;
 };
 
@@ -70,11 +70,11 @@ struct _GnomeProcBarClass {
 guint       gnome_proc_bar_get_type        (void);
 GtkWidget * gnome_proc_bar_new             (GtkWidget *label,
 					    gint n, GdkColor *colors,
-					    gint (*cb)());
+					    gint (*cb)(gpointer));
 void        gnome_proc_bar_construct       (GnomeProcBar *pb,
 					    GtkWidget *label,
 					    gint n, GdkColor *colors,
-					    gint (*cb)());
+					    gint (*cb)(gpointer));
 void        gnome_proc_bar_set_values      (GnomeProcBar *pb, const guint val []);
 void        gnome_proc_bar_set_orient      (GnomeProcBar *pb, gboolean vertical);
 void        gnome_proc_bar_start           (GnomeProcBar *pb, gint gtime, gpointer data);
